==> consul_1.8.7+dfsg1.orig.tar.xz: consul-1.8.7/logging/names.go <==
package logging

const (
	ACL                string = "acl"
	Agent              string = "agent"
	AntiEntropy        string = "anti_entropy"
	AutoEncrypt        string = "auto_encrypt"
	AutoConfig         string = "auto_config"
	Autopilot          string = "autopilot"
	AWS                string = "aws"
	Azure              string = "azure"
	CA                 string = "ca"
	Catalog            string = "catalog"
	CentralConfig      string = "central_config"
	ConfigEntry        string = "config_entry"
	Connect            string = "connect"
	Consul             string = "consul"
	ConsulClient       string = "client"
	ConsulServer       string = "server"
	Coordinate         string = "coordinate"
	DNS                string = "dns"
	Envoy              string = "envoy"
	FederationState    string = "federation_state"
	FSM                string = "fsm"
	GatewayLocator     string = "gateway_locator"
	HTTP               string = "http"
	Intentions         string = "intentions"
	Internal           string = "internal"
	KV                 string = "kvs"
	LAN                string = "lan"
	Leader             string = "leader"
	Legacy             string = "legacy"
	License            string = "license"
	Manager            string = "manager"
	Memberlist         string = "memberlist"
	MeshGateway        string = "mesh_gateway"
	Namespace          string = "namespace"
	NetworkAreas       string = "network_areas"
	Operator           string = "operator"
	PreparedQuery      string = "prepared_query"
	Proxy              string = "proxy"
	ProxyConfig        string = "proxycfg"
	Raft               string = "raft"
	Replication        string = "replication"
	Router             string = "router"
	RPC                string = "rpc"
	Serf               string = "serf"
	Session            string = "session"
	Sentinel           string = "sentinel"
	Snapshot           string = "snapshot"
	TerminatingGateway string = "terminating_gateway"
	TLSUtil            string = "tlsutil"
	Transaction        string = "txn"
	WAN                string = "wan"
	Watch              string = "watch"
	Vault              string = "vault"
)

==> consul_1.9.17+dfsg2.orig.tar.xz: consul-1.9.17/logging/names.go <==
package logging

const (
	ACL                string = "acl"
	Agent              string = "agent"
	AntiEntropy        string = "anti_entropy"
	AutoEncrypt        string = "auto_encrypt"
	AutoConfig         string = "auto_config"
	Autopilot          string = "autopilot"
	AWS                string = "aws"
	Azure              string = "azure"
	CA                 string = "ca"
	Catalog            string = "catalog"
	CentralConfig      string = "central_config"
	ConfigEntry        string = "config_entry"
	Connect            string = "connect"
	Consul             string = "consul"
	ConsulClient       string = "client"
	ConsulServer       string = "server"
	Coordinate         string = "coordinate"
	DNS                string = "dns"
	Envoy              string = "envoy"
	FederationState    string = "federation_state"
	FSM                string = "fsm"
	GatewayLocator     string = "gateway_locator"
	HTTP               string = "http"
	Intentions         string = "intentions"
	Internal           string = "internal"
	KV                 string = "kvs"
	LAN                string = "lan"
	Leader             string = "leader"
	Legacy             string = "legacy"
	License            string = "license"
	Manager            string = "manager"
	Memberlist         string = "memberlist"
	MeshGateway        string = "mesh_gateway"
	Namespace          string = "namespace"
	NetworkAreas       string = "network_areas"
	Operator           string = "operator"
	PreparedQuery      string = "prepared_query"
	Proxy              string = "proxy"
	ProxyConfig        string = "proxycfg"
	Raft               string = "raft"
	Replication        string = "replication"
	Router             string = "router"
	RPC                string = "rpc"
	Serf               string = "serf"
	Session            string = "session"
	Sentinel           string = "sentinel"
	Snapshot           string = "snapshot"
	TerminatingGateway string = "terminating_gateway"
	TLSUtil            string = "tlsutil"
	Transaction        string = "txn"
	UsageMetrics       string = "usage_metrics"
	UIServer           string = "ui_server"
	UIMetricsProxy     string = "ui_metrics_proxy"
	WAN                string = "wan"
	Watch              string = "watch"
	XDS                string = "xds"
	Vault              string = "vault"
)
